@@ -1,21 +1,55 @@
 """
 更新内容一览
 """
-
+"""
+2022/5/5
+control_version:0.5.8
+blcoklyFile_version:0.2.6
+blockly_version:2.2.2
+更新内容
+1、增加了兼容绝对路径和相对路径（适用于所有库）
+2、yuyin库大幅度修改
+3、unique库移植进了修改后的playsound库
 """
 
-control_version:0.5.5
+
+"""
+2022/4/30
+control_version:0.5.7
+blcoklyFile_version:0.2.5
+blockly_version:2.2.2
+更新内容
+1.加入摄像头判定语句，若为Win系统则不进行缩放（电脑算力足够）
+2.修改显示图像resize逻辑，直接写为640，320大小。（之前是放大两倍存在逻辑问题）
+更改了了blockly读取图片逻辑奇怪的问题
+contro对应加入了一个self.picture参数判断
+"""
+
+"""
+2022/4/29
+control_version:0.5.6
 blcoklyFile_version:0.2.4
 blockly_version:2.3.0
 更新内容：
-本地化语音转文字库和编程块
+修复了语音的若干个bug
+"""
+
+"""
+2022/4/20
+control_version:0.5.5
+blcoklyFile_version:0.2.4
+blockly_version:2.2.2
+更新内容：
+修复gpio无法直接使车辆停止的bug
+修复m.stop（）必须要加一个小前进速度的bug
+删除了没有的改变声音的语言块
 """
 
 """
 2020/4/4
 control_version:0.5.4
 blcoklyFile_version:0.2.3
-blockly_version:2.3.0
+blockly_version:2.2.1
 更新内容：
 修改了视觉部分，将摄像头分辨率降低到320✖240。但是最后的输出还是放大回了640✖480
 修改了舵机的块
@@ -83,4 +117,4 @@ blockly_version:2.2.1
 control_version:0.4.1
 blcoklyFile_version:0.1.1
 blockly_version:2.2.1
-"""
\ No newline at end of file
+"""
